==> zio-aws-rds_3-5.17.129.1-sources.jar: zio/aws/rds/model/ModifyDbProxyTargetGroupResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ModifyDbProxyTargetGroupResponse(
    dbProxyTargetGroup: scala.Option[zio.aws.rds.model.DBProxyTargetGroup] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.ModifyDbProxyTargetGroupResponse = {
    import ModifyDbProxyTargetGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.ModifyDbProxyTargetGroupResponse
      .builder()
      .optionallyWith(dbProxyTargetGroup.map(value => value.buildAwsValue()))(
        _.dbProxyTargetGroup
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.ModifyDbProxyTargetGroupResponse.ReadOnly =
    zio.aws.rds.model.ModifyDbProxyTargetGroupResponse.wrap(buildAwsValue())
}
object ModifyDbProxyTargetGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.ModifyDbProxyTargetGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.ModifyDbProxyTargetGroupResponse =
      zio.aws.rds.model.ModifyDbProxyTargetGroupResponse(
        dbProxyTargetGroup.map(value => value.asEditable)
      )
    def dbProxyTargetGroup
        : scala.Option[zio.aws.rds.model.DBProxyTargetGroup.ReadOnly]
    def getDbProxyTargetGroup
        : ZIO[Any, AwsError, zio.aws.rds.model.DBProxyTargetGroup.ReadOnly] =
      AwsError.unwrapOptionField("dbProxyTargetGroup", dbProxyTargetGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.ModifyDbProxyTargetGroupResponse
  ) extends zio.aws.rds.model.ModifyDbProxyTargetGroupResponse.ReadOnly {
    override val dbProxyTargetGroup
        : scala.Option[zio.aws.rds.model.DBProxyTargetGroup.ReadOnly] = scala
      .Option(impl.dbProxyTargetGroup())
      .map(value => zio.aws.rds.model.DBProxyTargetGroup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.ModifyDbProxyTargetGroupResponse
  ): zio.aws.rds.model.ModifyDbProxyTargetGroupResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-rds_3-5.17.169.1-sources.jar: zio/aws/rds/model/ModifyDbProxyTargetGroupResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ModifyDbProxyTargetGroupResponse(
    dbProxyTargetGroup: Optional[zio.aws.rds.model.DBProxyTargetGroup] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.ModifyDbProxyTargetGroupResponse = {
    import ModifyDbProxyTargetGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.ModifyDbProxyTargetGroupResponse
      .builder()
      .optionallyWith(dbProxyTargetGroup.map(value => value.buildAwsValue()))(
        _.dbProxyTargetGroup
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.ModifyDbProxyTargetGroupResponse.ReadOnly =
    zio.aws.rds.model.ModifyDbProxyTargetGroupResponse.wrap(buildAwsValue())
}
object ModifyDbProxyTargetGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.ModifyDbProxyTargetGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.ModifyDbProxyTargetGroupResponse =
      zio.aws.rds.model.ModifyDbProxyTargetGroupResponse(
        dbProxyTargetGroup.map(value => value.asEditable)
      )
    def dbProxyTargetGroup
        : Optional[zio.aws.rds.model.DBProxyTargetGroup.ReadOnly]
    def getDbProxyTargetGroup
        : ZIO[Any, AwsError, zio.aws.rds.model.DBProxyTargetGroup.ReadOnly] =
      AwsError.unwrapOptionField("dbProxyTargetGroup", dbProxyTargetGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.ModifyDbProxyTargetGroupResponse
  ) extends zio.aws.rds.model.ModifyDbProxyTargetGroupResponse.ReadOnly {
    override val dbProxyTargetGroup
        : Optional[zio.aws.rds.model.DBProxyTargetGroup.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbProxyTargetGroup())
        .map(value => zio.aws.rds.model.DBProxyTargetGroup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.ModifyDbProxyTargetGroupResponse
  ): zio.aws.rds.model.ModifyDbProxyTargetGroupResponse.ReadOnly = new Wrapper(
    impl
  )
}
